import sys
import os
import copy

class DataRow:
    """ A class for holding generic CSV data. """

    # Base variables
    colData = {}
    colName2Idx = {}
    colIdx2Name = {}
    id = -1
    NEXT_ID = 0

    # Internal variables
    error = False
    verbose = False
    ignoreError = False

    def __init__(self, lVerbose=False, lIgnoreError=False):
        self.verbose = lVerbose
        self.ignoreError = lIgnoreError
    # edef

    def copy(self):
        r = DataRow()
        r.verbose = self.verbose
        r.id = self.id
        r.colData = copy.copy(self.colData)
        r.colName2Idx = copy.copy(self.colName2Idx)
        r.colIdx2Name = copy.copy(self.colIdx2Name)
        return r
    #def

    def stampId(self):
        self.id = DataRow.NEXT_ID
        DataRow.NEXT_ID += 1
    # edef

    def printDataRow(self):
        print("---------------------")
        print("ID: %s" % self.id)
        for key in self.colData:
            print("%s: %s" % (key, self.colData[key]['value']))
        # efl
        print("---------------------")
    # edef

    def toRow(self):
        csvRow = ''
        for key in self.colData:
            csvRow += self.colData[key]['value'] + ","
        # efl

        csvRow = csvRow[:-1]
        csvRow += os.linesep
        return csvRow
    # edef

    def fromRow(self, csvRow):
        cols = csvRow.strip().split(',')
        colnum = 0
        for col in cols:
            self.setMember(colnum, col)
            colnum += 1
        # efl
    # edef

    def setMember(self, name, idx, val):
        try:
            self.colIdx2Name[idx] = name
            self.colName2Idx[name] = idx
            self.colData[name] = {'value': val, 'idx': idx}
            return True
        except:
            if self.ignoreError == False:
                self.error = True
            # eif

            if self.verbose:
                print("Error setting member with index: ", idx, " with value: ", val)
                print("Unexpected error:", sys.exc_info()[0])
            # eif
        # etry

        return False
    # edef

    def getMemberByIdx(self, idx):
        return self.colData[self.colIdx2Name[idx]]['value']
    # edef

    def getMemberByName(self, name):
        return self.colData[name]['value']
    # edef

# eclass